/*******************************************************************************
Copyright © 2023 Sebastian Roith

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*******************************************************************************/

(function(window) {

function createCheckerZusatzgeschwindigkeit(deltaX, deltaY) {
    return function() {
        if (!this.pfeile.length)
            return 'Zeichne zuerst die Zusatzgeschwindigkeit ein…';
        const lastPfeil = this.pfeile[this.pfeile.length - 1];
        return (lastPfeil.deltaX == deltaX && lastPfeil.deltaY == deltaY);
    }
}

const LEVELS = [
    {
        "task": "<p>Die Anfangsgeschwindigkeit eines Körpers und die Zusatzgeschwindigkeit, die der Körper erhält, sind jeweils eingezeichnet.</p><p>Ergänze die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario01.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-10, -10)
    },
    {
        "task": "<p>Die Anfangsgeschwindigkeit eines Körpers und die Zusatzgeschwindigkeit, die der Körper erhält, sind jeweils eingezeichnet.</p><p>Ergänze die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario02.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(0, -30)
    },
    {
        "task": "<p>Die Anfangsgeschwindigkeit eines Körpers und die Zusatzgeschwindigkeit, die der Körper erhält, sind jeweils eingezeichnet.</p><p>Ergänze die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario03.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-10, -25)
    },
    {
        "task": "<p>Die Anfangsgeschwindigkeit eines Körpers und die Zusatzgeschwindigkeit, die der Körper erhält, sind jeweils eingezeichnet.</p><p>Ergänze die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario04.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(5, 0)
    },
    {
        "task": "<p>Die Anfangsgeschwindigkeit eines Körpers und die Zusatzgeschwindigkeit, die der Körper erhält, sind jeweils eingezeichnet.</p><p>Ergänze die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario05.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-25, 0)
    },
    {
        "task": "<p>Die Anfangsgeschwindigkeit eines Körpers und die Zusatzgeschwindigkeit, die der Körper erhält, sind jeweils eingezeichnet.</p><p>Ergänze die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario06.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(15, -5)
    },
    {
        "task": "<p>Nun erhält der Körper erneut dieselbe Zusatzgeschwindigkeit.</p><p>Ergänze die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario07.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(10, 5)
    },
    {
        "task": "<p>Nun erhält der Körper erneut dieselbe Zusatzgeschwindigkeit.</p><p>Ergänze die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario08.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(5, 15)
    },
    {
        "task": "<p>Die Anfangsgeschwindigkeit eines Körpers und zwei Zusatzgeschwindigkeit, die der Körper erhält, sind eingezeichnet. Ergänze wieder die Endgeschwindigkeit des Körpers. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p><p>Tipp: Berücksichtige erst nur eine Zusatzgeschwindigkeit und ermittle dann erst, welche Geschwindigkeit aus der so ermittelten Geschwindigkeit und der zweiten Zusatzgeschwindigkeit resultiert.</p>",
        "shadows": [
            { type: 'image', src: 'szenario09.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-40, 15)
    },
    {
        "task": "<p>Anfangs hat ein Körper keine Geschwindigkeit. Er erhält aber die beiden eingezeichneten Zusatzgeschwindigkeiten. Bestimme wieder die Endgeschwindigkeit. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Endgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario10.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(5, 15)
    }
];

window.karokonstruktionTask = {
    levels: LEVELS
};
})(window);
